@@ -81,7 +81,7 @@ struct QueryOpt {
     /// Number of rows queried from the database on block. Larger numbers may reduce io overhead,
     /// but require more memory during execution.
     #[structopt(long, default_value = "5000")]
-    batch_size: u32,
+    batch_size: usize,
     /// Maximum string length in bytes. If omitted no limit is applied and the ODBC driver is taken
     /// for its word regarding the maximum length of the columns.
     #[structopt(long, short = "m")]
@@ -105,7 +105,7 @@ struct InsertOpt {
     /// Number of rows inserted into the database on block. Larger numbers may reduce io overhead,
     /// but require more memory during execution.
     #[structopt(long, default_value = "5000")]
-    batch_size: u32,
+    batch_size: usize,
     /// Path to the input csv file which is used to fill the database table with values. If
     /// omitted standard input is used.
     #[structopt(long, short = "i")]
@@ -245,7 +245,7 @@ fn query(environment: &Environment, opt: &QueryOpt) -> Result<(), Error> {
     };
     let mut writer = csv::Writer::from_writer(out);
 
-    let connection = open_connection(&environment, connect_opts)?;
+    let connection = open_connection(environment, connect_opts)?;
 
     // Convert the input strings into parameters suitable to for use with ODBC.
     let params: Vec<_> = parameters
@@ -254,7 +254,7 @@ fn query(environment: &Environment, opt: &QueryOpt) -> Result<(), Error> {
         .collect();
 
     // Execute the query as a one off, and pass the parameters.
-    match connection.execute(&query, params.as_slice())? {
+    match connection.execute(query, params.as_slice())? {
         Some(cursor) => {
             // Write column names.
             let headline: Vec<String> = cursor.column_names()?.collect::<Result<_, _>>()?;
@@ -304,7 +304,7 @@ fn insert(environment: &Environment, insert_opt: &InsertOpt) -> Result<(), Error
         Box::new(hold_stdin.lock())
     };
     let mut reader = csv::Reader::from_reader(input);
-    let connection = open_connection(&environment, connect_opts)?;
+    let connection = open_connection(environment, connect_opts)?;
 
     // Generate statement text from table name and headline
     let headline = reader.byte_headers()?;
